diff --git a/io_mesh_stl/blender_utils.py b/io_mesh_stl/blender_utils.py
index fdf353df2a1d32a68bf3cfb5bc235dcd1428efea..5c84152e930a959ae6501740d497561455ba71ba 100644
--- a/io_mesh_stl/blender_utils.py
+++ b/io_mesh_stl/blender_utils.py
@@ -48,7 +48,7 @@ def faces_from_mesh(ob, global_matrix, use_mesh_modifiers=False):
     """
     From an object, return a generator over a list of faces.
 
-    Each faces is a list of his vertexes. Each vertex is a tuple of
+    Each faces is a list of his vertices. Each vertex is a tuple of
     his coordinate.
 
     use_mesh_modifiers
diff --git a/io_mesh_stl/stl_utils.py b/io_mesh_stl/stl_utils.py
index 465806abcfb1d18878991e2f2b22b3df66465d54..e041c5276aca83bb234c4ab4f2692a7f6306b2be 100644
--- a/io_mesh_stl/stl_utils.py
+++ b/io_mesh_stl/stl_utils.py
@@ -168,7 +168,7 @@ def _binary_write(filepath, faces):
 
         for face in faces:
             # calculate face normal
-            # write normal + vertexes + pad as attributes
+            # write normal + vertices + pad as attributes
             fw(struct.pack('<3f', *normal(*face)) + pack(*itertools.chain.from_iterable(face)))
             # attribute byte count (unused)
             fw(b'\0\0')
diff --git a/io_scene_fbx/export_fbx_bin.py b/io_scene_fbx/export_fbx_bin.py
index c34a5182fb1bf04eb3a8bd9de9ca803295c89d51..f560b19c98bd2aa58008d4b5bec71b3033df184c 100644
--- a/io_scene_fbx/export_fbx_bin.py
+++ b/io_scene_fbx/export_fbx_bin.py
@@ -1528,7 +1528,7 @@ def fbx_data_armature_elements(root, arm_obj, scene_data):
             elem_data_single_int32(fbx_skin, b"Version", FBX_DEFORMER_SKIN_VERSION)
             elem_data_single_float64(fbx_skin, b"Link_DeformAcuracy", 50.0)  # Only vague idea what it is...
 
-            # Pre-process vertex weights (also to check vertices assigned ot more than four bones).
+            # Pre-process vertex weights (also to check vertices assigned to more than four bones).
             ob = ob_obj.bdata
             bo_vg_idx = {bo_obj.bdata.name: ob.vertex_groups[bo_obj.bdata.name].index
                          for bo_obj in clusters.keys() if bo_obj.bdata.name in ob.vertex_groups}
diff --git a/io_scene_gltf2/blender/exp/gltf2_blender_gather_animation_sampler_keyframes.py b/io_scene_gltf2/blender/exp/gltf2_blender_gather_animation_sampler_keyframes.py
index ba331b74ddbb4da13c7660183e98083b7a63e72a..53d789451084cf1f2b75ae756fe026d31d96355c 100755
--- a/io_scene_gltf2/blender/exp/gltf2_blender_gather_animation_sampler_keyframes.py
+++ b/io_scene_gltf2/blender/exp/gltf2_blender_gather_animation_sampler_keyframes.py
@@ -405,7 +405,7 @@ def gather_keyframes(blender_obj_uuid: str,
                     # for both in and out tangents, we guarantee that (even if there are errors or numerical imprecisions)
                     # symmetrical control points translate to symmetrical tangents.
                     # Note: I am not sure that linearity is never broken with quaternions and their normalization.
-                    # Especially at sign swap it might occure that the value gets negated but the control point not.
+                    # Especially at sign swap it might occur that the value gets negated but the control point not.
                     # I have however not once encountered an issue with this.
                     key.in_tangent = [
                         c.keyframe_points[i].co[1] + (c.keyframe_points[i].handle_left[1] - c.keyframe_points[i].co[1]) / (c.keyframe_points[i].handle_left[0] - c.keyframe_points[i].co[0])
diff --git a/io_scene_gltf2/blender/imp/gltf2_blender_pbrMetallicRoughness.py b/io_scene_gltf2/blender/imp/gltf2_blender_pbrMetallicRoughness.py
index d130f4e6b11d14a0593fcd21741dd3641d170e3e..b6b8e19f268880aeadb88ab0f66931eb16e57432 100755
--- a/io_scene_gltf2/blender/imp/gltf2_blender_pbrMetallicRoughness.py
+++ b/io_scene_gltf2/blender/imp/gltf2_blender_pbrMetallicRoughness.py
@@ -46,7 +46,7 @@ def pbr_metallic_roughness(mh: MaterialHelper):
     additional_location = 40, -370 # For occlusion and/or volume / original PBR extensions
 
     # Set IOR to 1.5, this is the default in glTF
-    # This value may be overidden later if IOR extension is set on file
+    # This value may be overridden later if IOR extension is set on file
     pbr_node.inputs['IOR'].default_value = GLTF_IOR
 
     if mh.pymat.occlusion_texture is not None or (mh.pymat.extensions and 'KHR_materials_specular' in mh.pymat.extensions):
@@ -610,7 +610,7 @@ def occlusion(mh: MaterialHelper, location, occlusion_socket):
 
 # => [Add Emission] => [Mix Alpha] => [Material Output] if needed, only for SpecGlossiness
 # => [Volume] => [Add Shader] => [Material Output] if needed
-# => [Velvet] => [Add Shader] => [Material Output] if nedded
+# => [Velvet] => [Add Shader] => [Material Output] if needed
 def make_output_nodes(
     mh: MaterialHelper,
     location,
diff --git a/materials_utils/functions.py b/materials_utils/functions.py
index 9397257a2d6c1be8063223d3528431791ccc20cb..93d700d880db59ad161cd2e37d90e142b11d86ab 100644
--- a/materials_utils/functions.py
+++ b/materials_utils/functions.py
@@ -333,7 +333,7 @@ def mu_select_by_material_name(self, find_material_name, extend_selection = Fals
             elif not internal:
                 # Some object types are not supported
                 #  mostly because don't really support selecting by material (like Font/Text objects)
-                #  ore that they don't support multiple materials/are just "weird" (i.e. Meta balls)
+                #  or that they don't support multiple materials/are just "weird" (i.e. Meta balls)
                 self.report({'WARNING'}, "The type '" +
                                             obj.type +
                                             "' isn't supported in Edit mode by Material Utilities!")
diff --git a/power_sequencer/operators/fade_add.py b/power_sequencer/operators/fade_add.py
index ab692dbaf3f01aeaf05608eb1c1bf5abc91c60f6..9a3d19731f6685e75f4a3fa395ec0e2d521cdbd2 100644
--- a/power_sequencer/operators/fade_add.py
+++ b/power_sequencer/operators/fade_add.py
@@ -13,7 +13,7 @@ class POWER_SEQUENCER_OT_fade_add(bpy.types.Operator):
     Fade options:
 
     - In, Out, In and Out create a fade animation of the given duration from
-    the start of the sequence, to the end of the sequence, or on boths sides
+    the start of the sequence, to the end of the sequence, or on both sides
     - From playhead: the fade animation goes from the start of sequences under the playhead to the playhead
     - To playhead: the fade animation goes from the playhead to the end of sequences under the playhead
 
diff --git a/power_sequencer/operators/mouse_trim_modal.py b/power_sequencer/operators/mouse_trim_modal.py
index e8f751c9f22dea8c615c310d87b109cf933c97fd..8136adae22db73115c737d51662c51044e8533f9 100644
--- a/power_sequencer/operators/mouse_trim_modal.py
+++ b/power_sequencer/operators/mouse_trim_modal.py
@@ -31,7 +31,7 @@ class POWER_SEQUENCER_OT_mouse_trim(bpy.types.Operator):
     *brief* Cut or Trim strips quickly with the mouse cursor
 
 
-    Click somehwere in the Sequencer to insert a cut, click and drag to trim
+    Click somewhere in the Sequencer to insert a cut, click and drag to trim
     With this function you can quickly cut and remove a section of strips while keeping or
     collapsing the remaining gap.
     Press <kbd>Ctrl</kbd> to snap to cuts.
diff --git a/precision_drawing_tools/pdt_tangent.py b/precision_drawing_tools/pdt_tangent.py
index 88abd2d0ee0baafb790c30f38f81e97015e16188..f9ccda51bc7b716e114fc67334911552299b5a95 100644
--- a/precision_drawing_tools/pdt_tangent.py
+++ b/precision_drawing_tools/pdt_tangent.py
@@ -199,8 +199,8 @@ def tangent_setup(context, pg, plane, obj_data, centre_0, centre_1, centre_2, ra
         obj_data: All the data of the chosen object
         centre_0: Centre coordinates of the first arc
         centre_1: Centre coordinates of the second arc
-        centre_2: Coordinates fo the point
-        radius_0: Radius if the first Arc
+        centre_2: Coordinates of the point
+        radius_0: Radius of the first Arc
         radius_1: Radius of the second Arc
 
     Returns:
diff --git a/render_povray/particles.py b/render_povray/particles.py
index 18cc0ac708cba2660144585e91d5bfd474487c0c..fdbd46477d2e0655bcf11558eaf8d3627ded077d 100644
--- a/render_povray/particles.py
+++ b/render_povray/particles.py
@@ -75,7 +75,7 @@ def export_hair(file, ob, mod, p_sys, global_matrix):
     # When you render, the entire dependency graph will be
     # evaluated at render resolution, including the particles.
     # In the viewport it will be at viewport resolution.
-    # So there is no need fo render engines to use this function anymore,
+    # So there is no need for render engines to use this function anymore,
     # it's automatic now.
     steps = p_sys_settings.display_step
     steps = 2**steps  # or + 1 # Formerly : len(particle.hair_keys)
diff --git a/rigify/rigs/limbs/limb_rigs.py b/rigify/rigs/limbs/limb_rigs.py
index f60666a04c35810faa143d80e1bc17a7680fbc6b..a094e17675dc28d23b45bfe5b61191d6e8b82362 100644
--- a/rigify/rigs/limbs/limb_rigs.py
+++ b/rigify/rigs/limbs/limb_rigs.py
@@ -959,7 +959,7 @@ class BaseLimbRig(BaseRig):
         params.limb_uniform_scale = bpy.props.BoolProperty(
             name        = "Support Uniform Scaling",
             default     = False,
-            description = "Suport uniformly scaling the limb via the gear control at the base"
+            description = "Support uniformly scaling the limb via the gear control at the base"
         )
 
         # Setting up extra layers for the FK and tweak
diff --git a/add_mesh_extra_objects/Blocks.py b/add_mesh_extra_objects/Blocks.py
index 226766708c9a5d863941cd6a4a458706816ddad3..c3dcd0d56085802a31208ddfbe70877d1533e493 100644
--- a/add_mesh_extra_objects/Blocks.py
+++ b/add_mesh_extra_objects/Blocks.py
@@ -269,7 +269,7 @@ def MakeABlock(bounds, segsize, vll=0, Offsets=None, FaceExclude=[],
     bounds: a list of boundary positions:
         0:left, 1:right, 2:bottom, 3:top, 4:back, 5:front
     segsize: the maximum size before lengthwise subdivision occurs
-    vll: the number of vertexes already in the mesh. len(mesh.verts) should
+    vll: the number of vertices already in the mesh. len(mesh.verts) should
             give this number.
     Offsets: list of coordinate delta values.
         Offsets are lists, [x,y,z] in
@@ -365,7 +365,7 @@ def MakeAKeystone(xpos, width, zpos, ztop, zbtm, thick, bevel, vll=0, FaceExclud
     zbtm: distance from zpos to the bottom
     thick: thickness
     bevel: the amount to raise the back vertex to account for arch beveling
-    vll: the number of vertexes already in the mesh. len(mesh.verts) should give this number
+    vll: the number of vertices already in the mesh. len(mesh.verts) should give this number
     faceExclude: list of faces to exclude from the faces list.
                  0:left, 1:right, 2:bottom, 3:top, 4:back, 5:front
     xBevScl: how much to divide the end (+- x axis) bevel dimensions.
@@ -779,7 +779,7 @@ class rowOb:
 
 def arch(ra, rt, x, z, archStart, archEnd, bevel, bevAngle, vll):
     __doc__ = """\
     Makes a list of faces and vertexes for arches.
     ra: the radius of the arch, to the center of the bricks
     rt: the thickness of the arch
     x: x center location of the circular arc, as if the arch opening were centered on x = 0
@@ -779,7 +779,7 @@ class rowOb:
 def arch(ra, rt, x, z, archStart, archEnd, bevel, bevAngle, vll):
     __doc__ = """\
-    Makes a list of faces and vertexes for arches.
+    Makes a list of faces and vertices for arches.
     ra: the radius of the arch, to the center of the bricks
     rt: the thickness of the arch
diff --git a/io_scene_gltf2/blender/com/gltf2_blender_ui.py b/io_scene_gltf2/blender/com/gltf2_blender_ui.py
index 406a15f1337f0a6e5f7da8fb2b0f947d02859f1d..0788bbbcf8946c4de85ea90d9bca7f0d3caa7f10 100644
--- a/io_scene_gltf2/blender/com/gltf2_blender_ui.py
+++ b/io_scene_gltf2/blender/com/gltf2_blender_ui.py
@@ -15,7 +15,7 @@ def create_gltf_ao_group(operator, group_name):
 
 class NODE_OT_GLTF_SETTINGS(bpy.types.Operator):
     bl_idname = "node.gltf_settings_node_operator"
-    bl_label  = "glTF Material Ouptut"
+    bl_label  = "glTF Material Output"
     bl_description = "Add a node to the active tree for glTF export"
 
     @classmethod
@@ -208,10 +208,10 @@ class SCENE_OT_gltf2_assign_to_variant(bpy.types.Operator):
 
         return {'FINISHED'}
 
 # Operator to reset mesh to orignal (using default material when exists)
 class SCENE_OT_gltf2_reset_to_original(bpy.types.Operator):
     bl_idname = "scene.gltf2_reset_to_original"
-    bl_label = "Reset to Orignal"
+    bl_label = "Reset to Original"
     bl_options = {'REGISTER'}
 
     @classmethod
@@ -208,10 +208,10 @@ class SCENE_OT_gltf2_assign_to_variant(bpy.types.Operator):
         return {'FINISHED'}
 
-# Operator to reset mesh to orignal (using default material when exists)
+# Operator to reset mesh to original (using default material when exists)
 class SCENE_OT_gltf2_reset_to_original(bpy.types.Operator):
     bl_idname = "scene.gltf2_reset_to_original"